// For float
@mixin float($side: left) {
  display: inline;
  float: $side; }

@mixin float-left {
    @include float(left); }

@mixin float-right {
    @include float(right); }

// For clearfix
@mixin clearfix {
    overflow: hidden;
    @include has-layout; }

// For IE has_layout
@mixin has-layout {
    zoom: 1; }

@mixin nowrap { white-space: nowrap; }
