@import "shared";

//  override to change the default
$default-background-size: 100% auto !default;

// Set the size of background images using px, width and height, or percentages.
// Currently supported in: Opera, Gecko, Webkit.
//
// * percentages are relative to the background-origin (default = padding-box)
// * mixin defaults to: `$default-background-size`
@mixin background-size($size: $default-background-size) {
  @if type-of($size) == string {
    $size: unquote($size);
  }
  @include experimental(background-size, $size, -moz, -webkit, -o, not -ms, not -khtml);
}
