$z-font-color: #444 !default;
$z-font-family: Georgia, serif !default;

$z-link-color: #607890 !default;
$z-link-hover-color: #036 !default;

$z-selection-fontcolor: #fff !default;
$z-selection-bgcolor: #ff5e99 !default;

$z-invalid-color: red !default;
$z-invalid-bgcolor: #f0dddd !default;
